import React from 'react';
import PropTypes from 'prop-types';
import { Form, Cascader, Switch, Input, Modal, Icon } from 'antd';
import * as city from '../../utils/city';

const FormItem = Form.Item

const formItemLayout = {
  labelCol: {
    span: 7,
  },
  wrapperCol: {
    span: 14,
  },
}

const ModalForm = ({
  item = {},
  onOk,
  form: {
    getFieldDecorator,
    getFieldsValue,
    validateFields,
  },
  ...modalProps,
}) => {
  const handleOk = () => {
    validateFields((errors) => {
      if (errors) {
        return
      }
      const data = {
        ...getFieldsValue(),
      };
      data.status ? data.status = 'NORMAL' : data.status = 'DEL';
      item.id ? data.id = item.id : null;
      onOk(data);
    })
  }

  const modalOpts = {
    ...modalProps,
    onOk: handleOk,
  }

  return (
    <Modal {...modalOpts}>
      <Form layout="horizontal">
        <FormItem label="终端编号：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('code', {
            initialValue: item.code,
          })(<Input disabled={true} placeholder="请输入"/>)}
        </FormItem>
        <FormItem label="终端名称：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('name', {
            initialValue: item.name,
          })(<Input placeholder="请输入"/>)}
        </FormItem>
        <FormItem label="终端密码：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('password', {
            initialValue: item.password,
          })(<Input placeholder="请输入" type="password" addonBefore={<Icon type="edit" />}/>)}
        </FormItem>
        <FormItem label="账号状态：" {...formItemLayout}>
          {getFieldDecorator('status', {
            valuePropsName: 'checked',
        })(<Switch defaultChecked={item.status === 'NORMAL' ? true : false} checkedChildren="使用中" unCheckedChildren="禁用中" />)}
        </FormItem>
      </Form>
    </Modal>
  )
}

ModalForm.propTypes = {
  item: PropTypes.object,
  form: PropTypes.object,
  type: PropTypes.string,
  onOk: PropTypes.func,
}

export default Form.create()(ModalForm);
